==> eam-wshub-proxyclient-11.4-8-sources.jar: net/datastream/schemas/mp_fields/CUSTOMERRENTALADJUSTMENTID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour CUSTOMERRENTALADJUSTMENTID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="CUSTOMERRENTALADJUSTMENTID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CUSTOMERRENTALADJUSTMENTPK"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CUSTOMERRENTALADJUSTMENTID_Type", propOrder = {
    "customerrentaladjustmentpk"
})
public class CUSTOMERRENTALADJUSTMENTID_Type {

    @XmlElement(name = "CUSTOMERRENTALADJUSTMENTPK", required = true)
    protected String customerrentaladjustmentpk;

    /**
     * Obtient la valeur de la propriété customerrentaladjustmentpk.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCUSTOMERRENTALADJUSTMENTPK() {
        return customerrentaladjustmentpk;
    }

    /**
     * Définit la valeur de la propriété customerrentaladjustmentpk.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCUSTOMERRENTALADJUSTMENTPK(String value) {
        this.customerrentaladjustmentpk = value;
    }

}

==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_fields/CUSTOMERRENTALADJUSTMENTID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for CUSTOMERRENTALADJUSTMENTID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="CUSTOMERRENTALADJUSTMENTID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CUSTOMERRENTALADJUSTMENTPK"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CUSTOMERRENTALADJUSTMENTID_Type", propOrder = {
    "customerrentaladjustmentpk"
})
public class CUSTOMERRENTALADJUSTMENTID_Type {

    @XmlElement(name = "CUSTOMERRENTALADJUSTMENTPK", required = true)
    protected String customerrentaladjustmentpk;

    /**
     * Gets the value of the customerrentaladjustmentpk property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCUSTOMERRENTALADJUSTMENTPK() {
        return customerrentaladjustmentpk;
    }

    /**
     * Sets the value of the customerrentaladjustmentpk property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCUSTOMERRENTALADJUSTMENTPK(String value) {
        this.customerrentaladjustmentpk = value;
    }

}
